package de.donmanfred;

import java.util.Iterator;

import com.google.firebase.FirebaseApp;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Logger.Level;
import com.google.firebase.database.Query;

import anywheresoftware.b4a.AbsObjectWrapper;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Author;
import anywheresoftware.b4a.BA.DependsOn;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.objects.collections.Map.MyMap;

@Version(1.01f)
@ShortName("FirebaseDatabase")
@Author(value = "DonManfred (wrapper)")
//@Permissions(values={"android.permission.INTERNET", "android.permission.ACCESS_NETWORK_STATE"})
//@Events(values={"onSigned(sign As Object)"})
@DependsOn(values={"firebase-server-sdk-3.0.1","json-20160810"})
/**
 * com.android.support:support-v4
 * com.android.support:appcompat-v7
 * com.android.support:cardview-v7
 * com.android.support:gridlayout-v7
 * com.android.support:mediarouter-v7
 * com.android.support:palette-v7
 * com.android.support:recyclerview-v
 * com.android.support:preference-v7
 * com.android.support:support-v13
 * com.google.firebase:firebase-database
 */

// @DesignerProperties(values = {
//		@Property(key="Checked", displayName="Checked", defaultValue="False", fieldType="Boolean")
//	})
public class FirebaseDatabaseWrapper extends AbsObjectWrapper<FirebaseDatabase> {
	private BA ba;
	private String eventName;

	/**
	 * Gets the instance of FirebaseDatabase 
	 * for the default FirebaseApp.
	 */
	public void Initialize(final BA ba, String EventName) {
		this.eventName = EventName.toLowerCase(BA.cul);
		this.ba = ba;

		final FirebaseDatabase _obj = FirebaseDatabase.getInstance();
		final String eventName = EventName.toLowerCase(BA.cul);
		setObject(_obj);
	}
	/**
	 * By default, this is set to INFO.
	 */
	public void setLogLevel(Level lvl){
		getObject().setLogLevel(lvl);
	}
	/**
	 * The Firebase Database client will cache synchronized 
	 * data and keep track of all writes you've initiated 
	 * while your application is running.
	 */
	public void setPersistenceEnabled(boolean persistence){
		getObject().setPersistenceEnabled(persistence);
	}

	/**
	 * Returns the FirebaseApp instance to 
	 * which this FirebaseDatabase belongs.
	 */
	public FirebaseApp getApp(){
		return getObject().getApp();
	}
	
	public Query orderByValue(){
		return getObject().getReference().orderByValue();
	}
	
	/**
	 * Gets a DatabaseReference for 
	 * the provided path.
	 */
	public DatabaseReference getReference(String path){
		return getObject().getReference(path);
	}
	/**
	 * Gets a DatabaseReference 
	 * for the provided URL.
	 */
	public DatabaseReference getReferencefromUrl(String url){
		return getObject().getReferenceFromUrl(url);
	}
	/**
	 * Shuts down our connection to the Firebase 
	 * Database backend until goOnline() is called.
	 */
	public void goOffline(){
		getObject().goOffline();
	}
	/**
	 * Resumes our connection to the Firebase 
	 * Database backend after a previous 
	 * goOffline() call.
	 */
	public void goOnline(){
		getObject().goOnline();
	}

	/**
	 * The Firebase Database client automatically 
	 * queues writes and sends them to the server 
	 * at the earliest opportunity, depending on 
	 * network connectivity.
	 */
	public void purgeOutstandingWrites(){
		getObject().purgeOutstandingWrites();
	}

	public Object Value2Map(Object value){
  	java.util.Map<Object, Object> mm = (java.util.Map<Object, Object>) value;
  	
  	MyMap map = new anywheresoftware.b4a.objects.collections.Map.MyMap();
  	for (Iterator it = mm.keySet().iterator(); it.hasNext(); ){
      Object key = it.next();
      Object val = mm.get(key);
      map.put(key, val);
  	}
  	return map;
	}

}
